@@ -1,8 +1,8 @@
-"""
 # Copyright (c) 2020 CNES
 #
 # All rights reserved. Use of this source code is governed by a
 # BSD-style license that can be found in the LICENSE file.
+"""
 Get software version information
 ================================
 """
@@ -10,9 +10,9 @@ Get software version information
 
 def release() -> str:
     """Returns the software version number"""
-    return "0.1.1"
+    return "0.2.0"
 
 
 def date() -> str:
     """Returns the creation date of this release"""
-    return "17 January 2020"
+    return "16 February 2020"
